Adapay Python SDK
===================================

 Adapay 官方 Python SDK。

下载
-----

官网下载压缩包，下载地址：
- https://docs.adapay.tech/sdk/03-pythonsdkaccess.html


安装
-----
如果已下载至本地：
pip install local_sdk_path_url

远程下载并安装：
pip install adapay

API 文档及接入文档
--------------------

- https://docs.adapay.tech/api/index.html
- https://docs.adapay.tech/sdk/03-pythonsdkaccess.html
